function [Ghat, confmat, pcc] = LDA_Eu(X, G)

% Function doing linear discriminant analysis based on squared Euclidean
% distances. 
%
% Inputs
% ------
% X: Data matrix of n measurements (rows) and p predictor variables
%    (columns).
% G: Group membership column vector.
%
% Outputs
% -------
% Ghat:    Model classifications of measurements in X.
% confmat: Confusion matrix.
% pcc:     Fraction of correct classifications.

n        = size(X, 1);     % # of measurements
K        = max(G);         % # of classes
d2       = zeros(n, K);    % init of d2
confmat  = zeros(K);       % init of confmat   
Gd       = dummyvar(G);    % dummy coding of G
muG      = (Gd'*Gd)\Gd'*X; % class centres

for i = 1:n
    for c = 1:K
        d2(i, c) = (X(i, :) - muG(c, :))*(X(i, :) - muG(c, :))'; % Eucl. dist ^2
    end
end

[~, Ghat] = min(d2, [], 2); % model predictions

for i = 1:n
    j = G(i);                          % actual class
    k = Ghat(i);                       % predicted class
    confmat(j, k) = confmat(j, k) + 1; % updates confmat
end

pcc = trace(confmat)/n; % fraction of correct classifications